@@ -276,6 +276,11 @@ func (c *giteaClient) CreateRelease(ctx *context.Context, body string) (string,
 	return strconv.FormatInt(release.ID, 10), nil
 }
 
+func (c *giteaClient) PublishRelease(_ *context.Context, _ string /* releaseID */) (err error) {
+	// TODO: Create release as draft while uploading artifacts and only publish it here.
+	return nil
+}
+
 func (c *giteaClient) ReleaseURLTemplate(ctx *context.Context) (string, error) {
 	downloadURL, err := tmpl.New(ctx).Apply(ctx.Config.GiteaURLs.Download)
 	if err != nil {
