@@ -16,6 +16,7 @@ var (
 	_ Client                = &Mock{}
 	_ ReleaseNotesGenerator = &Mock{}
 	_ PullRequestOpener     = &Mock{}
+	_ ForkSyncer            = &Mock{}
 )
 
 func NewMock() *Mock {
@@ -31,6 +32,7 @@ type Mock struct {
 	FailToUpload         bool
 	CreatedRelease       bool
 	UploadedFile         bool
+	ReleasePublished     bool
 	UploadedFileNames    []string
 	UploadedFilePaths    map[string]string
 	FailFirstUpload      bool
@@ -41,6 +43,12 @@ type Mock struct {
 	ReleaseNotes         string
 	ReleaseNotesParams   []string
 	OpenedPullRequest    bool
+	SyncedFork           bool
+}
+
+func (c *Mock) SyncFork(_ *context.Context, _ Repo, _ Repo) error {
+	c.SyncedFork = true
+	return nil
 }
 
 func (c *Mock) OpenPullRequest(_ *context.Context, _, _ Repo, _ string, _ bool) error {
@@ -81,6 +89,11 @@ func (c *Mock) CreateRelease(_ *context.Context, _ string) (string, error) {
 	return "", nil
 }
 
+func (c *Mock) PublishRelease(_ *context.Context, _ string /* releaseID */) (err error) {
+	c.ReleasePublished = true
+	return nil
+}
+
 func (c *Mock) ReleaseURLTemplate(_ *context.Context) (string, error) {
 	return "https://dummyhost/download/{{ .Tag }}/{{ .ArtifactName }}", nil
 }
