@@ -9,11 +9,11 @@ import (
 )
 
 func TestLogging(t *testing.T) {
-	require.NoError(t, Log("foo", func(ctx *context.Context) error {
+	require.NoError(t, Log("foo", func(_ *context.Context) error {
 		return nil
 	})(nil))
 
-	require.NoError(t, PadLog("foo", func(ctx *context.Context) error {
+	require.NoError(t, PadLog("foo", func(_ *context.Context) error {
 		log.Info("a")
 		return nil
 	})(nil))
