@@ -12,6 +12,7 @@ import (
 
 	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/client"
+	"github.com/goreleaser/goreleaser/internal/deprecate"
 	"github.com/goreleaser/goreleaser/internal/git"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -43,7 +44,12 @@ func (Pipe) Skip(ctx *context.Context) (bool, error) {
 	if ctx.Snapshot {
 		return true, nil
 	}
-	return tmpl.New(ctx).Bool(ctx.Config.Changelog.Skip)
+	if ctx.Config.Changelog.Skip != "" {
+		deprecate.Notice(ctx, "changelog.skip")
+		ctx.Config.Changelog.Disable = ctx.Config.Changelog.Skip
+	}
+
+	return tmpl.New(ctx).Bool(ctx.Config.Changelog.Disable)
 }
 
 // Run the pipe.
