@@ -97,6 +97,10 @@ func (Pipe) Default(ctx *context.Context) error {
 		if scoop.Name == "" {
 			scoop.Name = ctx.Config.ProjectName
 		}
+		if scoop.Folder != "" {
+			deprecate.Notice(ctx, "scoops.folder")
+			scoop.Directory = scoop.Folder
+		}
 		scoop.CommitAuthor = commitauthor.Default(scoop.CommitAuthor)
 		if scoop.CommitMessageTemplate == "" {
 			scoop.CommitMessageTemplate = "Scoop update for {{ .ProjectName }} version {{ .Tag }}"
@@ -180,7 +184,7 @@ func doRun(ctx *context.Context, scoop config.Scoop, cl client.ReleaseURLTemplat
 	}
 
 	filename := scoop.Name + ".json"
-	path := filepath.Join(ctx.Config.Dist, "scoop", scoop.Folder, filename)
+	path := filepath.Join(ctx.Config.Dist, "scoop", scoop.Directory, filename)
 	if err := os.MkdirAll(filepath.Dir(path), 0o755); err != nil {
 		return err
 	}
@@ -247,7 +251,7 @@ func doPublish(ctx *context.Context, manifest *artifact.Artifact, cl client.Clie
 	}
 
 	repo := client.RepoFromRef(scoop.Repository)
-	gpath := path.Join(scoop.Folder, manifest.Name)
+	gpath := path.Join(scoop.Directory, manifest.Name)
 
 	if scoop.Repository.Git.URL != "" {
 		return client.NewGitUploadClient(repo.Branch).
@@ -259,25 +263,36 @@ func doPublish(ctx *context.Context, manifest *artifact.Artifact, cl client.Clie
 		return err
 	}
 
-	if !scoop.Repository.PullRequest.Enabled {
-		return cl.CreateFile(ctx, author, repo, content, gpath, commitMessage)
+	base := client.Repo{
+		Name:   scoop.Repository.PullRequest.Base.Name,
+		Owner:  scoop.Repository.PullRequest.Base.Owner,
+		Branch: scoop.Repository.PullRequest.Base.Branch,
 	}
 
-	log.Info("brews.pull_request enabled, creating a PR")
-	pcl, ok := cl.(client.PullRequestOpener)
-	if !ok {
-		return fmt.Errorf("client does not support pull requests")
+	// try to sync branch
+	fscli, ok := cl.(client.ForkSyncer)
+	if ok && scoop.Repository.PullRequest.Enabled {
+		if err := fscli.SyncFork(ctx, repo, base); err != nil {
+			log.WithError(err).Warn("could not sync fork")
+		}
 	}
 
 	if err := cl.CreateFile(ctx, author, repo, content, gpath, commitMessage); err != nil {
 		return err
 	}
 
-	return pcl.OpenPullRequest(ctx, client.Repo{
-		Name:   scoop.Repository.PullRequest.Base.Name,
-		Owner:  scoop.Repository.PullRequest.Base.Owner,
-		Branch: scoop.Repository.PullRequest.Base.Branch,
-	}, repo, commitMessage, scoop.Repository.PullRequest.Draft)
+	if !scoop.Repository.PullRequest.Enabled {
+		log.Debug("scoop.pull_request disabled")
+		return nil
+	}
+
+	log.Info("scoop.pull_request enabled, creating a PR")
+	pcl, ok := cl.(client.PullRequestOpener)
+	if !ok {
+		return fmt.Errorf("client does not support pull requests")
+	}
+
+	return pcl.OpenPullRequest(ctx, base, repo, commitMessage, scoop.Repository.PullRequest.Draft)
 }
 
 // Manifest represents a scoop.sh App Manifest.
